@@ -10,17 +10,17 @@ if ($username=="" || $oldpassword=="" || $newpassword=="" || $newpassword!=$newp
 	include_once 'arg.php';
 	$eusername = encode_command_arg($username);
 	$eoldpassword =  encode_command_arg($oldpassword);
-	$md5newpassword = md5($newpassword);
-	$enewpassword = encode_command_arg($md5newpassword);
+	$md5saltnewpassword = md5("StarDict".$newpassword);
+	$enewpassword = encode_command_arg($md5saltnewpassword);
 	$args = "-cr ".$eusername." ".$eoldpassword." ".$enewpassword;
 	include_once 'backend.php';
 	$content = call_stardict_client($args);
 	if ($content=="") {
 		session_start();
-		$_SESSION['password'] = $md5newpassword;
+		$_SESSION['password'] = $md5saltnewpassword;
 		$cookpassword = isset($_COOKIE["StarDict_password"])?$_COOKIE["StarDict_password"]:"";
 		if ($cookpassword!="")
-			setcookie("StarDict_password", $md5newpassword, time()+60*60*24*30, '/');
+			setcookie("StarDict_password", $md5saltnewpassword, time()+60*60*24*30, '/');
 		echo "<center>Change password success!<br>Back to <a href=\"index.php\">Home</a> page.</center>";
 	} else {
 		echo $content;
