@@ -1,4 +1,4 @@
-<table><tbody><tr><td><a href="http://www.stardict.org"><img src="images/logo_sm.gif" alt="Go to StarDict Home" border="0" vspace="12" height="55" width="150"></a></td><td>&nbsp;&nbsp;</td>
+<table><tbody><tr><td><a href="./"><img src="images/logo_sm.gif" alt="Go to StarDict Home" border="0" vspace="12" height="55" width="150"></a></td><td>&nbsp;&nbsp;</td>
 <td>
 <?php echo "<table border=\"0\" cellpadding=\"4\" cellspacing=\"0\"><tbody><tr><td nowrap=\"nowrap\"><font size=\"-1\"><b>Web</b>&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"ajax.php\">Ajax</a>&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"news.php\">"._L("News")."</a>&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"forum/\">"._L("Forum")."</a>&nbsp;&nbsp;&nbsp;&nbsp;<b><a href=\"more.php\">"._L("more")."&nbsp;»</a></b></font></td></tr></tbody></table>";
 echo "<form action=\"query.php\" name=\"f\"><table cellpadding=\"0\" cellspacing=\"0\"><tbody><tr><td align=\"center\"><input maxlength=\"256\" size=\"31\" name=\"q\" value=\"\" title=\""._L("Query")."\"><input value=\""._L("Query")."\" type=\"submit\"></td><td nowrap=\"nowrap\" valign=\"top\" width=\"25%\"><font size=\"-1\">&nbsp;&nbsp;<a href=\"preferences.php\">"._L("Preferences")."</a><br>&nbsp;&nbsp;<a href=\"dictmanage.php\">"._L("Dict Manage")."</a></font></td></tr></tbody></table></form>";
